==> llm-docs-0.1.2.tgz: package/docs/components/bluefly_insights/INTEGRATION.md <==
---
id: components-bluefly_insights-INTEGRATION
---
# Integrating with Bluefly RFP Generator

This document provides detailed instructions for integrating the Bluefly Insights Drupal module with the RFP Generator application.

## Setting Up the Integration

### 1. Configure the Module Settings

In your Drupal administration interface, navigate to:

```
Administration → Configuration → Web services → Bluefly Insights
```

Configure these settings:

- **Export Directory**: Set to `.//BFRFP/data` to directly update the RFP Generator's data files
- **Enable Scheduled Exports**: Enable for automatic data updates
- **Export Frequency**: Choose based on your needs (daily recommended)
- **Data Types to Export**: Select all types
- **Enable Automatic Updates**: Enable to update exports when content changes
- **Enable GitLab Export**: Enable if using GitLab for CI/CD
- **GitLab API URL**: Your repository's API endpoint
- **GitLab Pipeline URL**: Your repository's pipeline trigger endpoint

### 2. Configure GitLab CI/CD Integration

Add the following job to your RFP Generator's `.gitlab-ci.yml` file:

```yaml
# Add this job to your existing CI/CD pipeline
fetch_drupal_data:
  stage: setup # Or appropriate stage in your pipeline
  image: alpine:latest
  script:
    - echo "Fetching latest data from Drupal JSON:API..."
    - apk add --no-cache curl jq
    - mkdir -p ${CI_PROJECT_DIR}/data/temp

    # Authenticate with OAuth if needed
    - |
      if [ -n "${DRUPAL_CLIENT_ID}" ] && [ -n "${DRUPAL_CLIENT_SECRET}" ]; then
        TOKEN=$(curl -X POST ${DRUPAL_SITE_URL}/oauth/token \
          -d "grant_type=client_credentials&client_id=${DRUPAL_CLIENT_ID}&client_secret=${DRUPAL_CLIENT_SECRET}" \
          | jq -r '.access_token')
        AUTH_HEADER="Authorization: Bearer ${TOKEN}"
      else
        AUTH_HEADER="X-API-KEY: ${DRUPAL_API_KEY}"
      fi

    # Fetch data using JSON:API endpoints (configured via Views Data Export)
    - curl -H "${AUTH_HEADER}" ${DRUPAL_SITE_URL}/api/insights/services.json > ${CI_PROJECT_DIR}/data/services/consolidated.json
    - curl -H "${AUTH_HEADER}" ${DRUPAL_SITE_URL}/api/insights/expertise.json > ${CI_PROJECT_DIR}/data/company/expertise.json
    - curl -H "${AUTH_HEADER}" ${DRUPAL_SITE_URL}/api/insights/team.json > ${CI_PROJECT_DIR}/data/team/collective_list.json
    - curl -H "${AUTH_HEADER}" ${DRUPAL_SITE_URL}/api/insights/focus-areas.json > ${CI_PROJECT_DIR}/data/services/focus_areas.json

    # Verify the fetched data
    - jq . ${CI_PROJECT_DIR}/data/services/consolidated.json > /dev/null || echo "Warning: services.json invalid format"
    - jq . ${CI_PROJECT_DIR}/data/company/expertise.json > /dev/null || echo "Warning: expertise.json invalid format"
    - jq . ${CI_PROJECT_DIR}/data/team/collective_list.json > /dev/null || echo "Warning: team.json invalid format"

    # Copy model to client directory if needed
    - |
      if [ -d "${ML_MODEL_PATH}" ]; then
        mkdir -p .//bfrfp_client/models
        cp ${ML_MODEL_PATH}/latest_model.json .//bfrfp_client/models/ || true
        cp ${ML_MODEL_PATH}/latest_metadata.json .//bfrfp_client/models/ || true
        echo "ML model copied to client directory"
      else
        echo "ML model path not found, skipping copy to client"
      fi

    - echo "Data update complete"
  artifacts:
    paths:
      - ${CI_PROJECT_DIR}/data/
  variables:
    DRUPAL_SITE_URL: '${DRUPAL_SITE_URL}' # Set in CI/CD variables
    # Choose authentication method:
    DRUPAL_API_KEY: '${DRUPAL_API_KEY}' # Simple API key (preferred)
    # Or OAuth credentials:
    # DRUPAL_CLIENT_ID: "${DRUPAL_CLIENT_ID}"
    # DRUPAL_CLIENT_SECRET: "${DRUPAL_CLIENT_SECRET}"
  needs:
    - install_dependencies
  # Add dependencies to this job as needed
```

### 3. Set Up Webhook Integration

For real-time updates when content changes in Drupal:

1. In your GitLab project, go to Settings → Webhooks
2. Add a new webhook with:
   - URL: `https://your-drupal-site.com/api/insights/gitlab-webhook`
   - Secret token: The same token you configured in the Drupal module
   - Trigger on: Push events, Pipeline events, and Merge request events

### 4. Configure Drupal Views for Data Export

The module creates several predefined Views for data export. If needed, you can customize these views at:

```
Administration → Structure → Views
```

Look for views with names starting with "Bluefly Insights".

## Testing the Integration

To test that everything is working correctly:

1. **Manual Export Test**:

   ```bash
   drush bluefly_insights:export all
   ```

2. **Check Export Files**:
   Verify that JSON files are created in the configured export directory.

3. **Trigger Pipeline Test**:

   ```bash
   drush bluefly_insights:trigger-pipeline
   ```

4. **View Statistics**:

   ```bash
   drush bluefly_insights:stats
   ```

## Troubleshooting

If you encounter issues with the integration:

1. Check Drupal logs at Reports → Recent log messages (filter for "bluefly_insights")
2. Check file permissions on the export directory
3. Verify API keys and tokens are correct
4. Test API endpoints directly using a tool like cURL or Postman
5. Check the CI/CD pipeline logs for any errors during the fetch job

## Support

For technical support with this integration, contact the Bluefly team at <support@bluefly.io>.

==> llm-docs-0.1.4.tgz: package/docs/components/bluefly_insights/INTEGRATION.md <==
---
id: components-bluefly_insights-INTEGRATION
---
# Integrating with LLM Platform RFP Generator

This document provides detailed instructions for integrating the LLM Platform Insights Drupal module with the RFP Generator application.

## Setting Up the Integration

### 1. Configure the Module Settings

In your Drupal administration interface, navigate to:

```
Administration → Configuration → Web services → LLM Platform Insights
```

Configure these settings:

- **Export Directory**: Set to `.//BFRFP/data` to directly update the RFP Generator's data files
- **Enable Scheduled Exports**: Enable for automatic data updates
- **Export Frequency**: Choose based on your needs (daily recommended)
- **Data Types to Export**: Select all types
- **Enable Automatic Updates**: Enable to update exports when content changes
- **Enable GitLab Export**: Enable if using GitLab for CI/CD
- **GitLab API URL**: Your repository's API endpoint
- **GitLab Pipeline URL**: Your repository's pipeline trigger endpoint

### 2. Configure GitLab CI/CD Integration

Add the following job to your RFP Generator's `.gitlab-ci.yml` file:

```yaml
# Add this job to your existing CI/CD pipeline
fetch_drupal_data:
  stage: setup # Or appropriate stage in your pipeline
  image: alpine:latest
  script:
    - echo "Fetching latest data from Drupal JSON:API..."
    - apk add --no-cache curl jq
    - mkdir -p ${CI_PROJECT_DIR}/data/temp

    # Authenticate with OAuth if needed
    - |
      if [ -n "${DRUPAL_CLIENT_ID}" ] && [ -n "${DRUPAL_CLIENT_SECRET}" ]; then
        TOKEN=$(curl -X POST ${DRUPAL_SITE_URL}/oauth/token \
          -d "grant_type=client_credentials&client_id=${DRUPAL_CLIENT_ID}&client_secret=${DRUPAL_CLIENT_SECRET}" \
          | jq -r '.access_token')
        AUTH_HEADER="Authorization: Bearer ${TOKEN}"
      else
        AUTH_HEADER="X-API-KEY: ${DRUPAL_API_KEY}"
      fi

    # Fetch data using JSON:API endpoints (configured via Views Data Export)
    - curl -H "${AUTH_HEADER}" ${DRUPAL_SITE_URL}/api/insights/services.json > ${CI_PROJECT_DIR}/data/services/consolidated.json
    - curl -H "${AUTH_HEADER}" ${DRUPAL_SITE_URL}/api/insights/expertise.json > ${CI_PROJECT_DIR}/data/company/expertise.json
    - curl -H "${AUTH_HEADER}" ${DRUPAL_SITE_URL}/api/insights/team.json > ${CI_PROJECT_DIR}/data/team/collective_list.json
    - curl -H "${AUTH_HEADER}" ${DRUPAL_SITE_URL}/api/insights/focus-areas.json > ${CI_PROJECT_DIR}/data/services/focus_areas.json

    # Verify the fetched data
    - jq . ${CI_PROJECT_DIR}/data/services/consolidated.json > /dev/null || echo "Warning: services.json invalid format"
    - jq . ${CI_PROJECT_DIR}/data/company/expertise.json > /dev/null || echo "Warning: expertise.json invalid format"
    - jq . ${CI_PROJECT_DIR}/data/team/collective_list.json > /dev/null || echo "Warning: team.json invalid format"

    # Copy model to client directory if needed
    - |
      if [ -d "${ML_MODEL_PATH}" ]; then
        mkdir -p .//bfrfp_client/models
        cp ${ML_MODEL_PATH}/latest_model.json .//bfrfp_client/models/ || true
        cp ${ML_MODEL_PATH}/latest_metadata.json .//bfrfp_client/models/ || true
        echo "ML model copied to client directory"
      else
        echo "ML model path not found, skipping copy to client"
      fi

    - echo "Data update complete"
  artifacts:
    paths:
      - ${CI_PROJECT_DIR}/data/
  variables:
    DRUPAL_SITE_URL: '${DRUPAL_SITE_URL}' # Set in CI/CD variables
    # Choose authentication method:
    DRUPAL_API_KEY: '${DRUPAL_API_KEY}' # Simple API key (preferred)
    # Or OAuth credentials:
    # DRUPAL_CLIENT_ID: "${DRUPAL_CLIENT_ID}"
    # DRUPAL_CLIENT_SECRET: "${DRUPAL_CLIENT_SECRET}"
  needs:
    - install_dependencies
  # Add dependencies to this job as needed
```

### 3. Set Up Webhook Integration

For real-time updates when content changes in Drupal:

1. In your GitLab project, go to Settings → Webhooks
2. Add a new webhook with:
   - URL: `https://your-drupal-site.com/api/insights/gitlab-webhook`
   - Secret token: The same token you configured in the Drupal module
   - Trigger on: Push events, Pipeline events, and Merge request events

### 4. Configure Drupal Views for Data Export

The module creates several predefined Views for data export. If needed, you can customize these views at:

```
Administration → Structure → Views
```

Look for views with names starting with "LLM Platform Insights".

## Testing the Integration

To test that everything is working correctly:

1. **Manual Export Test**:

   ```bash
   drush bluefly_insights:export all
   ```

2. **Check Export Files**:
   Verify that JSON files are created in the configured export directory.

3. **Trigger Pipeline Test**:

   ```bash
   drush bluefly_insights:trigger-pipeline
   ```

4. **View Statistics**:

   ```bash
   drush bluefly_insights:stats
   ```

## Troubleshooting

If you encounter issues with the integration:

1. Check Drupal logs at Reports → Recent log messages (filter for "bluefly_insights")
2. Check file permissions on the export directory
3. Verify API keys and tokens are correct
4. Test API endpoints directly using a tool like cURL or Postman
5. Check the CI/CD pipeline logs for any errors during the fetch job

## Support

For technical support with this integration, contact the LLM Platform team at <support@bluefly.io>.
